Changelog
=========


0.1.3 (2026-03-24)
------------------

- Added Plone 6.1 version in buildout.
  [chris-adam]
- Refactored storage utility initialization without zope ready subscriber.
  [sgeulette]
- Renamed log method from utils.fplog to utils.fpalog to distinguish it from imio.helpers.security.fplog.
  [sgeulette]

0.1.2 (2025-03-12)
------------------

- Avoid test isolation problems by setting the default value of `log_entries`
  during install.
  [gbastien]

0.1.1 (2025-02-28)
------------------

- Corrected buildout
  [sgeulette]
- Pinned natsort.
  [sgeulette]
- Improved uninstall profile.
  [sgeulette]

0.1.0 (2025-02-20)
------------------

- Initial release.
  [sgeulette]
